{% extends 'base.html' %}
{% block content %}
    <table class="table">
      <thead>
        <tr>
          <th scope="col">First</th>
          <th scope="col">Last</th>
          <th scope="col">Email</th>
            <th scope="col">Username</th>
        </tr>
      </thead>
      <tbody>
      {% if users is defined and users != None %}
        {% for user in users %}
        <tr>

          <td>{{ user.first_name }}</td>
          <td>{{ user.last_name }}</td>
            <td>{{ user.email }}</td>
          <td>{{ user.user_name}}</td>
        </tr>
        {% endfor %}
      {% endif %}
      </tbody>
    </table>
{% endblock %}