{% extends "base.html" %}
{% block content %}
    <div class="container">
        <h1 class="text-center">Create Playlist</h1>
        <form action="/playlist/create" method="post">
            <div class="mb-3">
                <label class="form-label" for="playlist_name">Playlist Name:</label>
                <input class="form-control" name="playlist_name" id="playlist_name" type="text">
            </div>
            <button type="submit" class="btn btn-primary">Create</button>
        </form>
    </div>
{% endblock %}