.e3_2 {
	overflow:hidden;
}
.e3_2 { 
	background-color:rgba(47.0000009983778, 48.000000938773155, 58.00000034272671, 1);
	width:1920px;
	height:1080px;
	position:absolute;
}
.e4_29 { 
	width:2031px;
	height:1007px;
	position:absolute;
	left:-60px;
	top:128px;
}
.e4_25 { 
	border-radius:500px;
	background-color:rgba(23.000000528991222, 98.00000175833702, 167.00000524520874, 0.10000000149011612);
	width:215px;
	height:213px;
	position:absolute;
	left:0px;
	top:0px;
}
.e4_26 { 
	border-radius:500px;
	background-color:rgba(188.0000039935112, 58.00000034272671, 128.0000075697899, 0.10000000149011612);
	width:349px;
	height:319px;
	position:absolute;
	left:1682px;
	top:688px;
}
.e4_27 { 
	border-radius:500px;
	background-color:rgba(23.000000528991222, 98.00000175833702, 167.00000524520874, 0.10000000149011612);
	width:295px;
	height:256px;
	position:absolute;
	left:1445px;
	top:156px;
}
.e4_28 { 
	border-radius:500px;
	background-color:rgba(188.0000039935112, 58.00000034272671, 128.0000075697899, 0.10000000149011612);
	width:297px;
	height:274px;
	position:absolute;
	left:767px;
	top:621px;
}
.e3_3 { 
	color:rgba(255, 255, 255, 1);
	width:619px;
	height:196px;
	position:absolute;
	left:970px;
	top:321px;
	font-family:Roboto;
	text-align:left;
	font-size:72px;
	letter-spacing:0;
}
.e4_4 { 
	color:rgba(255, 255, 255, 1);
	width:1022px;
	height:146px;
	position:absolute;
	left:970px;
	top:419px;
	font-family:Roboto;
	text-align:left;
	font-size:36px;
	letter-spacing:0;
}
.e4_8 { 
	width:250px;
	height:92px;
	position:absolute;
	left:970px;
	top:540px;
}
.e4_5 { 
	background-color:rgba(23.000000528991222, 98.00000175833702, 167.00000524520874, 1);
	width:250px;
	height:92px;
	position:absolute;
	left:0px;
	top:0px;
	border-top-left-radius:10px;
	border-top-right-radius:10px;
	border-bottom-left-radius:10px;
	border-bottom-right-radius:10px;
}
.e4_6 { 
	color:rgba(255, 255, 255, 1);
	width:250px;
	height:91px;
	position:absolute;
	left:0px;
	top:0px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_193 { 
	width:1920px;
	height:106px;
	position:absolute;
	left:0px;
	top:47px;
}
.e4_194 { 
	background-color:rgba(0, 0, 0, 1);
	width:1920px;
	height:106px;
	position:absolute;
	left:0px;
	top:0px;
}
.e4_195 { 
	color:rgba(255, 255, 255, 1);
	width:141px;
	height:37px;
	position:absolute;
	left:187px;
	top:33px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_196 { 
	color:rgba(255, 255, 255, 1);
	width:141px;
	height:37px;
	position:absolute;
	left:437px;
	top:33px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_197 { 
	color:rgba(255, 255, 255, 1);
	width:141px;
	height:37px;
	position:absolute;
	left:682px;
	top:32px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_198 { 
	color:rgba(255, 255, 255, 1);
	width:141px;
	height:37px;
	position:absolute;
	left:927px;
	top:32px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_199 { 
	color:rgba(255, 255, 255, 1);
	width:160px;
	height:37px;
	position:absolute;
	left:1172px;
	top:32px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_200 { 
	color:rgba(255, 255, 255, 1);
	width:160px;
	height:37px;
	position:absolute;
	left:1436px;
	top:34px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_201 { 
	color:rgba(255, 255, 255, 1);
	width:160px;
	height:37px;
	position:absolute;
	left:1700px;
	top:34px;
	font-family:Poppins;
	text-align:center;
	font-size:24px;
	letter-spacing:0;
}
.e4_202 { 
	width:60px;
	height:60px;
	position:absolute;
	left:31px;
	top:23px;
}
.e4_204 {
	overflow:hidden;
}
.e4_204 { 
	width:34.99028015136719px;
	height:15.25px;
	position:absolute;
	left:10.996928215026855px;
	top:21.350006103515625px;
}
.e4_203 { 
	border-radius:500px;
	width:60px;
	height:60px;
	position:absolute;
	left:0px;
	top:0px;
}
.e4_213 { 
	background-image:linear-gradient(0deg, rgba(23.000000528991222, 98.00000175833702, 167.00000524520874, 1) 0%,rgba(188.0000039935112, 58.00000034272671, 128.0000075697899, 1) 100%) ;
	width:54.98472213745117px;
	height:18.299999237060547px;
	position:absolute;
	left:2.9991791248321533px;
	top:19.316680908203125px;
}
