{% extends 'base.html' %}
{% block content %}
    <div class="container mt-5">
        {% include 'forms/login.html' %}
    </div>
    {% if message is defined %}
        <div class="toast show" role="alert" aria-live="assertive" aria-atomic="true">
          <div class="toast-header">
            <strong class="me-auto">Message</strong>
            <button type="button" class="btn-close" data-bs-dismiss="toast" aria-label="Close"></button>
          </div>
          <div class="toast-body">
            {{ message }}
          </div>
        </div>
    {% endif %}
{% endblock %}